"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppBootstrapper = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const core_1 = require("@nestjs/core");
const swagger_1 = require("@nestjs/swagger");
const nestjs_core_1 = require("@sftech/nestjs-core");
const cookie_parser_1 = tslib_1.__importDefault(require("cookie-parser"));
const nest_winston_1 = require("nest-winston");
const global_execption_filter_1 = require("./exception/global-execption.filter");
const logging_1 = require("./infrastructure/logging");
class AppBootstrapper {
    static async run(mainModule, config) {
        const app = await core_1.NestFactory.create(mainModule, {
            logger: nest_winston_1.WinstonModule.createLogger({
                level: config.logging?.enableDebugLogs ? 'debug' : 'info',
                transports: this._getTransports(config.appName, config.logging),
            }),
        });
        app.setGlobalPrefix(nestjs_core_1.Configuration.getValue('APP_API_PREFIX'));
        app.use((0, cookie_parser_1.default)());
        app.enableCors();
        app.useGlobalFilters(new global_execption_filter_1.GlobalExceptionFilter(app.get(common_1.Logger)));
        if (config.swagger) {
            const swaggerConfig = new swagger_1.DocumentBuilder()
                .setTitle(config.swagger.title ?? 'NestJS-Angular-Blueprint')
                .setDescription(config.swagger.description ?? 'API description for basic nestjs crud functionality')
                .setVersion(config.swagger.version ?? '1.0')
                .build();
            const document = swagger_1.SwaggerModule.createDocument(app, swaggerConfig);
            swagger_1.SwaggerModule.setup(config.swagger.path ?? 'api/swagger', app, document, {});
        }
        await app.listen(nestjs_core_1.Configuration.getValue('APP_PORT'), nestjs_core_1.Configuration.getValue('APP_HOST')).then(async () => {
            app.get(common_1.Logger).log(`Server is running on ${await app.getUrl()}`);
        });
    }
    static _getTransports(appName, loggingConfig) {
        if (!appName) {
            appName = 'App';
        }
        const transports = [];
        if (loggingConfig?.filePath) {
            transports.push(logging_1.Logging.getWinstonFileTransport(appName, loggingConfig.filePath));
        }
        if (loggingConfig?.enableDebugLogs) {
            transports.push(logging_1.Logging.getWinstonConsoleDebugTransport(appName));
        }
        else {
            transports.push(logging_1.Logging.getWinstonConsoleTransport(appName));
        }
        return transports;
    }
}
exports.AppBootstrapper = AppBootstrapper;
//# sourceMappingURL=bootstrap-app.js.map