"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Configuration = void 0;
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("fs"));
const configuration_key_not_found_exception_1 = require("../exception/configuration-key-not-found.exception");
const configuration_not_found_exception_1 = require("../exception/configuration-not-found.exception");
const configuration_not_valid_json_exception_1 = require("../exception/configuration-not-valid-json.exception");
class Configuration {
    static _config;
    static getValue(key) {
        if (process.env[key] !== undefined) {
            return process.env[key];
        }
        if (Configuration._config === undefined) {
            throw new configuration_not_found_exception_1.ConfigurationNotFoundException();
        }
        if (Configuration._config[key] === undefined) {
            throw new configuration_key_not_found_exception_1.ConfigurationKeyNotFoundException(key);
        }
        return Configuration._config[key];
    }
    static load(configPath) {
        let fileContent = '';
        try {
            fileContent = fs.readFileSync(configPath, 'utf8');
        }
        catch {
            throw new configuration_not_found_exception_1.ConfigurationNotFoundException(configPath);
        }
        let config = {};
        try {
            config = JSON.parse(fileContent);
        }
        catch {
            throw new configuration_not_valid_json_exception_1.ConfigurationNotValidJsonException();
        }
        Configuration._config = config;
    }
}
exports.Configuration = Configuration;
//# sourceMappingURL=configuration.js.map